@@ -48,12 +48,7 @@ def exec_input(input, capsys, shell_args=None):
     (client, alias_to_cmd) = prepare_shell(shell_args)
     params = parse_cmd(input)
     cmd = alias_to_cmd.get(params[0])
-    try:
-        cmd.execute(client, params)
-    except Exception as err:
-        breakpoint()
-        traceback.print_exc()
-        raise
+    cmd.execute(client, params)
     return capsys.readouterr().out
 
 def test_account_hint(capsys):
@@ -84,6 +79,7 @@ def test_account_write(capsys):
 
 def test_mint_account(capsys):
     output = exec_input("a m 0 123", capsys)
+    assert 'Error' not in output
     assert 'Mint' in output
 
 def test_query_hint(capsys):
@@ -141,7 +137,7 @@ def test_execute_script_on_testnet(capsys):
     balance = client.get_balance(a0.address_hex)
     if balance <= 1:
         try:
-            client.mint_coins(a0.address_hex, 9999999, True)
+            client.mint_coins(a0.address_hex, a0.auth_key_prefix, 9999999, True)
         except Exception:
             params = {
                 "receiver_account_address": a0.address_hex,
@@ -150,7 +146,8 @@ def test_execute_script_on_testnet(capsys):
             import requests
             requests.post("http://apitest.moveonlibra.com/v1/transactions/mint_mol", data=params)
     addr1 = wallet.accounts[1].address.hex()
-    output = exec_input(f"dev e 0 test/peer_to_peer.mv {addr1} 1", capsys)
+    addr1_prefix = 'b"'+wallet.accounts[1].auth_key_prefix.hex()+'"'
+    output = exec_input(f"dev e 0 test/peer_to_peer.mv {addr1} {addr1_prefix} 1", capsys)
     assert 'Compiling program' in output
     if TESTNET_LOCAL:
         if "MempoolError" in output:
